<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG -perusmoduuli';
$lang['admindescription'] = 'T&auml;m&auml; moduuli sallii p&auml;&auml;asiassa sis&auml;ll&ouml;n, mutta mahdollisesti my&ouml;s muunkin datan muokkaamisen WYSIWYG editorilla.';
$lang['uninstalled'] = 'Moduuli poistettu.';
$lang['installed'] = 'Moduulin versio %s asennettu.';
$lang['stripbackgroundtags'] = 'Poista taustatagit CSS:st&auml;';
$lang['stiptags_help'] = 'T&auml;m&auml; asetus yritt&auml;&auml; poistaa background-tyyppiset asetukset tyylitiedostoista.';
$lang['source_formatting_text'] = 'Muotoile tulostettavaa HTML:&auml;&auml;';
$lang['dropdownblockformats_text'] = 'Blockformats alasvetovalikossa';
$lang['allowtables'] = 'Salli taulukko-operaatiot';
$lang['newlinestyle_text'] = 'Uuden rivin tyyli';
$lang['pstyle'] = 'p-tyyli';
$lang['brstyle'] = 'br-tyyli';
$lang['usecompressiontext'] = 'K&auml;yt&auml; gz-pakkausta';
$lang['usecompressionhelp'] = 'T&auml;m&auml; voi nopeuttaa TinyMCE:n latautumista, mutta voi my&ouml;s joissain j&auml;rjestelmiss&auml; est&auml;&auml; sen latautumisen. K&auml;yt&auml; varoen.';
$lang['forcedrootblocktext'] = 'Pakota &amp;lt;p&amp;gt; juurielementti';
$lang['forcedrootblockhelp'] = 'Pakottaa palautetun sis&auml;ll&ouml;n olevan ainakin suljettuna &amp;lt;p&amp;gt;-tagiin';
$lang['filepickerstyle'] = 'Tiedostovalitsemen tyyli';
$lang['filepickersize'] = 'Tiedostovalitsemen koko';
$lang['allowuploadtext'] = 'Salli tiedostojen l&auml;hett&auml;minen ja hakemistojen luominen Tiedostovalitsemassa';
$lang['allowscalingtext'] = 'Salli l&auml;hetettyjen kuvien koon muuttaminen lennossa';
$lang['scalingdimensionstext'] = 'Oletuskoko';
$lang['resizeto'] = 'Muuta kooksi:';
$lang['makethumbnail'] = 'Luo pienoiskuva, kun kuva l&auml;hetet&auml;&auml;n';
$lang['useadvancedprofile'] = 'K&auml;yt&auml; monipuolisempaa TinyMCE-profiilia';
$lang['saveprofile'] = 'Tallenna profiili';
$lang['profilesaved'] = 'Profiili tallennettu';
$lang['profiles_tab'] = 'Profiilit';
$lang['advanced_backend_toolbars'] = 'Monipuolisemmat taustaprofiilien asetukset';
$lang['savestyles'] = 'Tallenna tyylit';
$lang['allowadvancedprofile'] = 'Salli monipuolisempien profiilien k&auml;ytt&auml;minen TinyMCE:ss&auml;';
$lang['showfilemanagement'] = 'N&auml;yt&auml; tiedostonhallinnan asetukset';
$lang['showfilemanagementhelp'] = 'N&auml;yt&auml; tiedostonhallinta asetuksissa, kuten tiedostojen l&auml;hetys, hakemistojen luominen ja tiedostojen poistaminen Tiedostovalitsemassa, jos k&auml;ytt&auml;j&auml;ll&auml; on lupa suorittaa n&auml;it&auml; toimintoja.';
$lang['restrictdirs'] = 'Rajoita k&auml;ytt&auml;j&auml;n p&auml;&auml;sy&auml; hakemistoihin';
$lang['restrictdirshelp'] = 'T&auml;m&auml; rajoittaa k&auml;ytt&auml;j&auml;n p&auml;&auml;syn tiedostonhallinnass ainoastaan uploads-hakemiston alihakemistoon, joka on saman niminen kuin k&auml;ytt&auml;j&auml;n tunnus. Jos hakemistoa ei ole olemassa, voidaan se luoda. Huomaa, ett&auml; t&auml;m&auml; toimii t&auml;ll&auml; hetkell&auml; ainoastaan oletushakemistostoissa, uploads/images. T&auml;m&auml; voi muuttua tulevaisuudessa.';
$lang['deleteconfirmation'] = 'Oletko varma, ett&auml; haluat poistaa tiedoston?';
$lang['deletefilesuccess'] = 'poistettiin onnistuneesti';
$lang['deletefilefailed'] = 'ei voitu poistaa';
$lang['deletesubdirfailed'] = 'ei voitu poistaa';
$lang['deletesubdirsuccess'] = 'poistettiin onnistuneesti';
$lang['deletedirconfirmation'] = 'Oletko varma, ett&auml; t&auml;m&auml; tyhj&auml; hakemisto poistetaan?';
$lang['deletedir'] = 'Poista tyhj&auml; alihakemisto';
$lang['deletefile'] = 'Poista tiedosto';
$lang['cannotreadconfig'] = 'Ei voida lukea tiedostoa tinyconfig.php, joten TinyMCE ei todenn&auml;k&ouml;isesti toimi. Sinun tulisi tarkistaa tiedoston ja yl&auml;hakemistojen oikeudet, joiden pit&auml;isi olla kaikkien luettavissa, mutta omistajan kirjoitettavissa.';
$lang['filenameonly'] = 'N&auml;yt&auml; tiedostonimet';
$lang['thumbnailsonly'] = 'N&auml;yt&auml; pienoiskuvat';
$lang['showthumbnailfilestext'] = 'N&auml;yt&auml; pienoiskuvat tavallisina tiedostoina';
$lang['filenameandthumbnails'] = 'N&auml;yt&auml; sek&auml; tiedostonimet ett&auml; pienoiskuvat';
$lang['skinstext'] = 'Ulkoasu';
$lang['skinvariationtext'] = 'Ulkoasun muunnos';
$lang['advancedwarning'] = '<strong>Huomaa!<br/>N&auml;iden asetusten muuttaminen voi est&auml;&auml; TinyMCE:n toiminnan tai luotu koodi voi olla virheellist&auml;. Muokkaa ainoastaan, jos tied&auml;t mit&auml; teet! Katso lis&auml;tietoa TinyMCE:n kotisivuilta ennen kuin jatkat.</strong>';
$lang['entityencoding_text'] = 'Merkkien muunnokset';
$lang['rawencoding'] = 'Raaka muunnos (nopein, toimii useimmissa tapauksissa)';
$lang['namedencoding'] = 'Nimetty muunnos (kuten &nbsp;)';
$lang['numericencoding'] = 'Numeerinen muunnos (kuten &amp;#160;)';
$lang['show_path_text'] = 'N&auml;yt&auml; elementin polku editorin alaosassa.';
$lang['toolbar_tab'] = 'Ty&ouml;kalupalkki';
$lang['toolbar_help'] = 'N&auml;iden tulisi sis&auml;lt&auml;&auml; pilkulla erotettu lista painikkeiden/kontrollien nimist&auml;, jotka sijoitetaan ty&ouml;kalupalkkiin.';
$lang['toolbar_text'] = 'Ty&ouml;kalupalkki';
$lang['toolbarhelptext'] = 'Klikkaa t&auml;st&auml; n&auml;hd&auml;ksesi ty&ouml;kalupalkin ohjeet TinyMCE:n wikiss&auml;.';
$lang['editor_width_text'] = 'Editorikent&auml;n leveys';
$lang['editor_height_text'] = 'Editorikent&auml;n korkeus';
$lang['auto'] = 'Automaattinen';
$lang['or'] = 'tai';
$lang['testarea_tab'] = 'Testaus alue';
$lang['showtestingoutput'] = 'N&auml;yt&auml; testaus tulokset';
$lang['testareaeditor'] = 'Testaus alueen editori';
$lang['testareaoutput'] = 'Testaus alueen tulokset';
$lang['testareaoutputsource'] = 'Testaus alueen l&auml;hde';
$lang['allowresizing'] = 'Salli editointikent&auml;n koon muuttaminen paikallaan';
$lang['resizenone'] = '&Auml;l&auml; salli koon muuttamista';
$lang['resizeboth'] = 'Salli koon muutttaminen molempiin suuntiin';
$lang['resizeheight'] = 'Salli vain korkeuden muuttaminen';
$lang['datetimeformat_text'] = 'P&auml;iv&auml;m&auml;&auml;r&auml;- ja aikamuoto';
$lang['timetext'] = 'Aika';
$lang['datetext'] = 'P&auml;iv&auml;m&auml;&auml;r&auml;';
$lang['datetimeformat_help'] = 'Klikkaa t&auml;st&auml;, jos haluat ohjeita p&auml;iv&auml;m&auml;&auml;r&auml;- ja aikamuotoihin';
$lang['extraconfigtext'] = 'Lis&auml;asetukset';
$lang['extraconfighelp2'] = 'Yksi m&auml;&auml;ritys per rivi, pilkut lis&auml;t&auml;&auml;n ennen ja j&auml;lkeen sis&auml;lt&ouml;&auml;. Katso TinyMCE:n wikist&auml; lis&auml;ohjeita.';
$lang['customdropdowntext'] = 'Oma pudotusvalikko';
$lang['customdropdownhelp'] = 'Lis&auml;&auml; omia p&auml;tki&auml; koodia/teksti&auml; pudotusvalikkoon. Selkein k&auml;ytt&ouml;kohde on helppo tagien k&auml;ytt&auml;minen. Valikko lis&auml;t&auml;&auml;n ty&ouml;kalupalkkiin k&auml;ytt&auml;en &#039;customdropdown&#039;-asetusta.';
$lang['startenabledtext'] = 'K&auml;ynnistys p&auml;&auml;ll&auml;';
$lang['startenabledhelp'] = 'T&auml;m&auml;n ottaminen pois k&auml;yt&ouml;st&auml; k&auml;ynnist&auml;&auml; TinyMCE:n poissa k&auml;yt&ouml;st&auml;. T&auml;t&auml; tulisi k&auml;ytt&auml;&auml; yhdess&auml; p&auml;&auml;lle/pois-painikkeen kanssa.';
$lang['loadcmslinkertext'] = 'Lataa CMS-linkitt&auml;j&auml;';
$lang['loadcmslinkerhelp'] = 'T&auml;m&auml; luo JavaScript-koodin, joka sallii cmslinkerin lis&auml;&auml;misen ty&ouml;kalupalkkiin.';
$lang['cmslinkerstyletext'] = 'CMS-linkitt&auml;j&auml;n linkkityyli';
$lang['cmsselflinkstyle'] = '{cms_selflink}-tyyli';
$lang['ahrefstyle'] = '<a href>-tyyli';
$lang['cmslinkeraddstext'] = 'CMS-linker lis&auml;ykset';
$lang['cmslinkeraddshelp'] = 'T&auml;m&auml; mahdollistaa parametrien lis&auml;&auml;misen &amp;lt;a href&amp;gt; tai {cms_selflink} -tagiin, kun generoidaan CMS-linkerill&auml;.';
$lang['avoidlinkconversiontext'] = 'V&auml;lt&auml; linkki muunnoksia';
$lang['avoidlinkconversionhelp'] = 'Poistaa k&auml;yt&ouml;st&auml; TinyMCE:n oman linkki convertterin. Mahdollistaa {smarty}:n k&auml;yt&ouml;n urleissa.';
$lang['relativeurlstext'] = 'Luo relatiiviset url-osoitteet';
$lang['forcecleanpastetext'] = 'Pakota koodin siistiminen liitt&auml;misess&auml;';
$lang['forcecleanpastehelp'] = 'T&auml;m&auml; tulisi olla p&auml;&auml;ll&auml;, jotta oudot muotoilut poistetaan koodista, kun liitet&auml;&auml;n teksti&auml; esimerkiksi Wordista.';
$lang['bodycss_text'] = 'Body-tagin CSS';
$lang['bodycss_help'] = 'J&auml;t&auml; tyhj&auml;ksi tai aseta oletus k&auml;ytt&auml;&auml;ksesi sivun CSS:&auml;&auml;. Huomaa: Asettaaksesi editorin taustav&auml;rin valkoiseksi, anna seuraava arvo: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Sis&auml;llyt&auml; ainoastaan n&auml;ytt&ouml; CSS';
$lang['includeonlyscreencss_help'] = 'T&auml;m&auml;n valitseminen ainoastaan tyylitiedostojen liitt&auml;misen TinyMCE:hen, joilla on mediatyyppi screen valittuna.';
$lang['usestaticconfigtext'] = 'K&auml;yt&auml; staattista konfiguraatiotiedostoa';
$lang['usestaticconfighelp'] = 'T&auml;m&auml; voi helpottaa TinyMCE:n saamista toimintaan sellaisessa ymp&auml;rist&ouml;ss&auml;, jossa palveluntarjoaja lis&auml;&auml; palveluja kuten tilastoja kaikkeen ulosmenev&auml;&auml;n tietoon, joka rikkoo dynaamisesti luodun JavaScript konfiguraatiotiedoston';
$lang['usestaticconfigwarning'] = 'Varoitus! Sinulla on staattinen konfiguraatiotiedosto k&auml;yt&ouml;ss&auml;, mutta hakemisto /tmp/ ei ole kirjoitettavissa. T&auml;m&auml; est&auml;&auml; moduulia tallentamasta staattista konfiguraatiotiedostoa ja est&auml;&auml; TinyMCE:n toiminnan.';
$lang['ignoremodifyfilestext'] = '&Auml;l&auml; v&auml;lit&auml; &#039;Muokata tiedostoja&#039;-oikeudesta Tiedostovalitsimessa.';
$lang['ignoremodifyfileshelp'] = 'Varoitus! T&auml;m&auml; sallii joidenkin tiedostojen muokkaustoimintojen tekemisen, vaikka k&auml;ytt&auml;j&auml;ryhm&auml;ll&auml; ei ole &#039;Muokata tiedostoja&#039;-oikeutta. T&auml;t&auml; voi tehokkaasti k&auml;ytt&auml;&auml; asetuksen kanssa, joka rajoittaa k&auml;ytt&auml;j&auml;n hakemistoihin p&auml;&auml;sy&auml;.';
$lang['showtogglebutton_text'] = 'N&auml;yt&auml; wysiwyg p&auml;&auml;lle/pois-painike';
$lang['togglewysiwyg'] = 'WYSIWYG p&auml;&auml;lle/pois';
$lang['styles_tab'] = 'CSS-tyylit';
$lang['styles_help'] = 'Jos j&auml;t&auml;t ensimm&auml;isen kent&auml;n tyhj&auml;ksi, TinyMCE k&auml;sittelee CSS-tiedostosi ja listaa sen sis&auml;lt&auml;m&auml;t tyylit k&auml;ytt&auml;j&auml;lle. Jos haluat vain joidenkin tyylien n&auml;kyv&auml;n k&auml;ytt&auml;j&auml;lle, m&auml;&auml;rittele ne t&auml;h&auml;n tapaan: \&quot;Style 1=style1; Style 2=style2\&quot; ensimm&auml;isess&auml; alla olevassa kent&auml;ss&auml;. Muissa kentiss&auml; voit m&auml;&auml;ritell&auml; CSS-tyylej&auml; taulukoille, riveille ja soluille, joita k&auml;ytet&auml;&auml;n vastaavissa dialogeissa. Jos kentt&auml; on tyhj&auml;, k&auml;ytet&auml;&auml;n yleisi&auml; tyylej&auml;';
$lang['css_styles_text'] = 'Tyylit';
$lang['accessdenied'] = 'P&auml;&auml;sy estetty. Tarkista oikeudet.';
$lang['error'] = 'Virhe!';
$lang['submit'] = 'L&auml;het&auml;';
$lang['update'] = 'P&auml;ivit&auml;';
$lang['savesettings'] = 'Talleta asetukset';
$lang['settings'] = 'Asetukset';
$lang['settingssaved'] = 'Asetukset tallennettu';
$lang['saveadvanced'] = 'Talleta monipuoliset asetukset';
$lang['advancedsaved'] = 'Monipuoliset asetukset tallennettu';
$lang['toolbarsaved'] = 'Ty&ouml;kalupalkki tallennettu';
$lang['stylessaved'] = 'Tyylit tallennettu';
$lang['testareatext'] = '<p>Testialue, sis&auml;lt&ouml; ei sotkeennu t&auml;t&auml; muokatessa...</p>';
$lang['reset'] = 'Palauta oletukset';
$lang['resetall'] = 'Palauta kaikki asetukset oletuksiin';
$lang['confirmreset'] = 'Oletko varma, ett&auml; haluat palauttaa n&auml;m&auml; asetukset oletuksiin?';
$lang['confirmresetall'] = 'Oletko varma, ett&auml; haluat palauttaa KAIKKI asetukset oletuksiin?';
$lang['settingsreset'] = 'N&auml;m&auml; asetukset palautettiin oletuksiin';
$lang['allsettingsreset'] = 'Kaikki asetukset palautettiin oletuksiin';
$lang['upgraded'] = 'on p&auml;ivitetty versioon %s';
$lang['customdropdown'] = 'Oma pudotusvalikko';
$lang['cmsmslinker'] = 'Lis&auml;&auml; linkki cmsms-sivulle';
$lang['backend_toolbars'] = 'Hallintapaneelin profiiliasetukset';
$lang['frontend_toolbars'] = 'Julkisen sivun profiiliasetukset';
$lang['plugins_tab'] = 'Lis&auml;osat';
$lang['plugins_help'] = 'Valitse, mitk&auml; lis&auml;osat haluat aktivoida. Dokumentaatio l&ouml;ytyy <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">t&auml;&auml;lt&auml;</a>';
$lang['plugins_text'] = 'Lis&auml;osat';
$lang['saveplugins'] = 'Tallenna lis&auml;osat';
$lang['pluginssaved'] = 'Lis&auml;osat tallennettu';
$lang['plugins_module'] = 'Moduulin lis&auml;osat';
$lang['plugins_common'] = 'Yleiset lis&auml;osat';
$lang['module'] = 'Moduuli';
$lang['description'] = 'Kuvaus';
$lang['plugin'] = 'Lis&auml;osa';
$lang['youareintext'] = 'Olet kohdassa';
$lang['loadstylesheettext'] = 'Lataa tyylitiedosto sis&auml;ll&ouml;lle (suositeltua)';
$lang['extrastylestext'] = 'Lis&auml;ykset tyylitiedostoihin';
$lang['extrastyleshelp'] = 'T&auml;h&auml;n lis&auml;tty CSS lis&auml;t&auml;&auml;n tyylitiedostoon, jonka TinyMCE lukee, kun hakee CMSMS:n tyylit';
$lang['uploadnewfile'] = 'Uusi tiedosto';
$lang['uploadfile'] = 'L&auml;het&auml;';
$lang['createnewdir'] = 'Uusi hakemisto';
$lang['createdir'] = 'Luo';
$lang['nodirname'] = 'Ei hakemiston nime&auml; annettuna';
$lang['direxists'] = 'Hakemiston nimi on jo olemassa';
$lang['newdircreated'] = 'Uusi hakemisto luotu onnistuneesti';
$lang['newdirfailed'] = 'Tapahtui virhe hakemistoa luotaessa';
$lang['nofile'] = 'Tiedostoa ei l&auml;hetetty';
$lang['filetoobig'] = 'L&auml;hetett&auml;v&auml; tiedosto on liian suuri';
$lang['containsillegalchars'] = 'Tiedoston nimi sis&auml;lt&auml;&auml; yhden tai useamman kielletyn merkin (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Virhe l&auml;hetetyn tiedoston siirt&auml;misess&auml;';
$lang['fileuploaded'] = 'Tiedosto l&auml;hetettiin onnistuneesti';
$lang['notanimage'] = 'L&auml;hetett&auml;v&auml; tiedosto ei ole kuva';
$lang['filepickertitle'] = 'CMSMadeSimple tiedoston valitseminen';
$lang['success'] = 'Onnistui';
$lang['fileoperations'] = 'Tiedostotyoiminnot';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Koko';
$lang['dimensions'] = 'LxK';
$lang['advanced_tab'] = 'Monipuolinen';
$lang['help'] = '<h3>Mit&auml; t&auml;m&auml; tekee?</h3>
	<p>Asettaa k&auml;ytt&ouml;&ouml;n TinyMCE:n k&auml;ytt&auml;misen WYSIWYG-editorina.</p>
	<h3>Kuinka k&auml;yt&auml;n sit&auml;?</h3>
	<p>Asenna se, mene sen j&auml;lkeen k&auml;ytt&auml;j&auml;n asetuksiin ja valitse onko TinyMCE k&auml;yt&ouml;ss&auml;.</p>
  <h3>Kielentarkistus</h3>
  <p>Versiosta 2.6.0 l&auml;htien TinyMCE sis&auml;lt&auml;&auml; verkossa olevan kielentarkistuksen. Huomaa, ett&auml; palvelimen asetuksissa t&auml;ytyy olla SSL p&auml;&auml;lle, jotta t&auml;m&auml; toimisi. Joissain asennuksissa on vaihtoehto nimelt&auml; php_openssl, mutta se voi vaihdella</p>
	<h3>Ongelmien etsiminen</h3>
	Osalla ihmisist&auml; on ongelmia saada TinyMCE n&auml;kym&auml;&auml;n asennuksen tai p&auml;ivityksen j&auml;lkeen. T&auml;ss&auml; on tarkistuslista, jonka voit k&auml;yd&auml; l&auml;pi ennen kuin kysyt apua.
	<br/>
	<ul>
	<li>1. Ole kiltti ja yrit&auml; l&auml;hett&auml;&auml; modules/TinyMCE hakemisto palvelimellesi. Et usko, kuinka usein t&auml;m&auml; on auttanut ihmisi&auml;..</li>	
	<li>2. Jos p&auml;ivitit uuteen versioon, yrit&auml; palauttaa oletusasetukset. T&auml;m&auml; ei ole mukavaa, jos olet tehnyt paljon muutoksia, mutta versioiden 2.3.x ja 2.4.x v&auml;lill&auml; on tapahtunut paljon muutoksia moduuliin.
	<li>3. Yrit&auml; laittaa p&auml;&auml;lle staattinen konfiguraatiotiedosto monipuolisissa asetuksssa. T&auml;m&auml; toimii osassa j&auml;rjestelmist&auml; paremmin (kuten CGI-pohjaisissa). Huomaa, ett&auml; /tmp/-hakemistoon t&auml;ytyy pysty&auml; kirjoittamaan.
	</ul>
	<br/>
  <h3>Lis&auml;osan kehitt&auml;minen</h3>
 Versiosta 2.7.0 l&auml;htien TinyMCE-moduulissa on mahdollista muiden moduulien rekister&ouml;id&auml; lis&auml;yksi&auml; siihen. Se voi esimerkiksi oma ikoni, joka sallii sis&auml;lt&ouml;jen lis&auml;&auml;misen toisesta moduulista, esimerkiksi Galleriasta. T&auml;m&auml;n tekeminen on suhteellisen teknist&auml; tietoa, mutta jos olet moduulin kehitt&auml;j&auml; ja olet kiinnostunut t&auml;st&auml;, ole hyv&auml; ja katso lis&auml;tietoa TinyMCE/docs -hakemistosta.';
$lang['utma'] = '156861353.144823811.1251375439.1288623556.1288630766.361';
$lang['utmz'] = '156861353.1285804076.330.37.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['qca'] = 'P0-1379893105-1252067779694';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1288630766';
?>